"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const OrqlToSql_1 = __importDefault(require("./sql/OrqlToSql"));
const SchemaManager_1 = __importDefault(require("./SchemaManager"));
exports.SchemaManager = SchemaManager_1.default;
const OrqlResultMapper_1 = __importDefault(require("./mapper/OrqlResultMapper"));
const ResultMapper_1 = __importDefault(require("./mapper/ResultMapper"));
class Configuration {
    constructor(options) {
        switch (options.dialect) {
            case 'mysql':
                const MysqlDriver = require('./database/Mysql');
                const MysqlDialect = require('./dialect/MysqlDialect');
                const MsqlMigration = require('./migration/MysqlMigration');
                this.database = new MysqlDriver(this.connectionOptions);
                this.dialect = new MysqlDialect();
                this.migration = new MsqlMigration();
                break;
            case 'sqlite3':
                const SqliteDriver = require('./database/Sqlite3');
                const SqliteDialect = require('./dialect/SqliteDialect3');
                const SqliteMigration = require('./migration/Sqlite3Migration');
                this.database = new SqliteDriver(this.connectionOptions);
                this.dialect = new SqliteDialect();
                this.migration = new SqliteMigration();
                break;
        }
        this.schemaManager = new SchemaManager_1.default();
        this.orqlToSql = new OrqlToSql_1.default(this.schemaManager, this.dialect);
        this.resultMapper = new ResultMapper_1.default();
        this.orqlResultMapper = new OrqlResultMapper_1.default(this.schemaManager);
        this.connectionOptions = options.connection;
    }
}
exports.default = Configuration;
