"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Configuration_1 = __importDefault(require("./Configuration"));
const Session_1 = __importDefault(require("./Session"));
class OrqlMapper {
    constructor(options) {
        this.configuration = new Configuration_1.default(options);
    }
    async newSession() {
        const connect = await this.configuration.database.getConnect(this.configuration.connectionOptions);
        return new Session_1.default(this.configuration, connect);
    }
    /**
     * add schema
     * @param name  schema name
     * @param columns columns data type or column options or association options
     * @param options
     */
    addSchema(name, columns, options) {
        return this.configuration.schemaManager.addSchema(name, columns, options);
    }
    getSchema(name) {
        return this.configuration.schemaManager.getSchema(name);
    }
    async sync(type) {
        const session = await this.newSession();
        const migration = this.configuration.migration;
        switch (type) {
            case 'create':
                await migration.create(session);
                break;
            case 'update':
                await migration.update(session);
                break;
            case 'drop':
                await migration.drop(session);
                await migration.create(session);
                break;
        }
        await session.close();
    }
}
exports.default = OrqlMapper;
