"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class QueryBuilder {
    constructor(session) {
        this._params = {};
        this.session = session;
    }
    page(page, size) {
        this._page = page;
        if (size != undefined)
            this._size = size;
        return this;
    }
    size(size) {
        this._size = size;
        return this;
    }
    offset(offset) {
        this._offset = offset;
        return this;
    }
    limit(limit) {
        this._limit = limit;
        return this;
    }
    orql(orql) {
        this._orql = orql;
        return this;
    }
    param(key, value) {
        this._params[key] = value;
        return this;
    }
    async queryOne() {
        return await this.session.query(this._orql, this._params);
    }
    async queryAll() {
        if (this._page != undefined && this._size != undefined) {
            this._offset = (this._page - 1) * this._size;
            this._limit = this._size;
        }
        return await this.session.query(this._orql, this._params, { offset: this._offset, limit: this._limit });
    }
    async count() {
        return await this.session.query(this._orql, this._params);
    }
}
exports.default = QueryBuilder;
