"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Schema_1 = __importDefault(require("./Schema"));
class SchemaManager {
    constructor() {
        this.schemas = [];
        this.addAssociationMap = new Map();
    }
    getSchema(name) {
        return this.schemas.find(schema => schema.name == name);
    }
    hasSchema(name) {
        return this.schemas.find(schema => schema.name == name) != undefined;
    }
    addSchema(name, columns, options) {
        const schema = new Schema_1.default(this, name, options);
        this.schemas.push(schema);
        for (const key of Object.keys(columns)) {
            const options = columns[key];
            if (typeof options == 'string') {
                // data type
                schema.addColumn(key, { type: options });
            }
            else if ('refName' in options) {
                if (this.hasSchema(options.refName)) {
                    // association
                    schema.addAssociation(key, options);
                }
                else {
                    const refName = options.refName;
                    let adds;
                    if (this.addAssociationMap.has(refName)) {
                        adds = this.addAssociationMap.get(refName);
                    }
                    else {
                        adds = [];
                        this.addAssociationMap.set(refName, adds);
                    }
                    adds.push({ current: schema, name: key, options: options });
                }
            }
            else {
                // column
                schema.addColumn(key, options);
            }
        }
        const adds = this.addAssociationMap.get(name);
        if (adds) {
            adds.forEach(({ current, name, options }) => current.addAssociation(name, options));
            this.addAssociationMap.delete(name);
        }
        return schema;
    }
    removeSchema(name) {
        const index = this.schemas.findIndex(schema => schema.name == name);
        this.schemas.splice(index, 1);
    }
    toJSON() {
        const array = [];
        for (const v of this.schemas.values()) {
            array.push(v);
        }
        return array;
    }
}
exports.default = SchemaManager;
