import Configuration, { SchemaManager } from './Configuration';
import { Connection, QueryResult } from './database/Database';
import { Params } from './sql/NamedParamSql';
import QueryBuilder from './QueryBuilder';
import UpdateBuilder from './UpdateBuilder';
import Schema from './Schema';
import ResultMapper from './mapper/ResultMapper';
import NativeBuilder from './NativeBuilder';
export default class Session {
    readonly configuration: Configuration;
    readonly schemaManager: SchemaManager;
    private orqlToSql;
    private connection;
    readonly resultMapper: ResultMapper;
    private orqlResultMapper;
    constructor(configuration: Configuration, connection: Connection);
    private parse;
    beginTransaction(): Promise<void>;
    commit(): Promise<void>;
    rollback(): Promise<void>;
    close(): Promise<void>;
    getSchema(name: string): Schema | undefined;
    query(orql: string, params: Params, options?: {
        offset?: number;
        limit?: number;
    }): Promise<any>;
    add(orql: string, params?: Params): Promise<any>;
    update(orql: string, params?: Params): Promise<number>;
    delete(orql: string, params?: Params): Promise<number>;
    nativeQuery(sql: string, params?: Params): Promise<QueryResult>;
    nativeUpdate(sql: string, params?: Params): Promise<number>;
    buildQuery(): QueryBuilder;
    buildUpdate(): UpdateBuilder;
    buildNative(): NativeBuilder;
}
