"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const orql_parser_1 = __importDefault(require("orql-parser"));
const NamedParamSql_1 = __importDefault(require("./sql/NamedParamSql"));
const QueryBuilder_1 = __importDefault(require("./QueryBuilder"));
const UpdateBuilder_1 = __importDefault(require("./UpdateBuilder"));
const NativeBuilder_1 = __importDefault(require("./NativeBuilder"));
class Session {
    // private parser: Parser;
    constructor(configuration, connection) {
        this.connection = connection;
        this.configuration = configuration;
        this.schemaManager = configuration.schemaManager;
        this.orqlToSql = configuration.orqlToSql;
        this.resultMapper = configuration.resultMapper;
        this.orqlResultMapper = configuration.orqlResultMapper;
    }
    parse(orql) {
        return orql_parser_1.default.parse(orql);
    }
    async beginTransaction() {
        await this.connection.beginTransaction();
    }
    async commit() {
        await this.connection.commit();
    }
    async rollback() {
        await this.connection.rollback();
    }
    async close() {
        await this.connection.close();
    }
    getSchema(name) {
        return this.schemaManager.getSchema(name);
    }
    async query(orql, params, options = {}) {
        const node = this.parse(orql);
        const sql = this.orqlToSql.toQuery(node, { offset: options.offset, limit: options.limit });
        const { results, fields } = await this.connection.query(new NamedParamSql_1.default(sql, params));
        // count
        if (node.op == 'count')
            return results[0][fields[0]];
        const mapper = this.orqlResultMapper.toResult(node.item);
        const mapperResult = this.resultMapper.mappe(mapper, results);
        if (!node.item.isArray) {
            // object
            return mapperResult.length > 0 ? mapperResult[0] : undefined;
        }
        // array
        return mapperResult;
    }
    async add(orql, params = {}) {
        const node = this.parse(orql);
        const sql = this.orqlToSql.toAdd(node, params);
        // 代理params 判断defaultValue和initialValue
        return this.connection.add(new NamedParamSql_1.default(sql, params));
    }
    async update(orql, params = {}) {
        const node = this.parse(orql);
        const sql = this.orqlToSql.toUpdate(node);
        return this.connection.update(new NamedParamSql_1.default(sql, params));
    }
    async delete(orql, params = {}) {
        const node = this.parse(orql);
        const sql = this.orqlToSql.toDelete(node);
        return this.connection.delete(new NamedParamSql_1.default(sql, params));
    }
    async nativeQuery(sql, params = {}) {
        return await this.connection.query(new NamedParamSql_1.default(sql, params));
        // return mapper ? this.resultMapper.mappe(mapper, results) : results;
    }
    async nativeUpdate(sql, params) {
        params = params || {};
        return this.connection.update(new NamedParamSql_1.default(sql, params));
    }
    buildQuery() {
        return new QueryBuilder_1.default(this);
    }
    buildUpdate() {
        return new UpdateBuilder_1.default(this);
    }
    buildNative() {
        return new NativeBuilder_1.default(this);
    }
}
exports.default = Session;
