"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class UpdateBuilder {
    constructor(session) {
        this.session = session;
    }
    async add(name, data) {
        const schema = this.session.getSchema(name);
        const items = [];
        for (const key of Object.keys(data)) {
            if (schema.hasColumn(key) || schema.hasAssociation(key)) {
                if (data[key] != undefined) {
                    items.push(key);
                }
            }
        }
        if (items.length == 0)
            return;
        const orql = `add ${name}: {${items.join(', ')}}`;
        const idValue = await this.session.add(orql, data);
        const idColumn = schema.getIdColumn();
        if (idColumn && idColumn.generatedKey)
            data[idColumn.name] = idValue;
        return idValue;
    }
    async delete(name, data) {
        const schema = this.session.getSchema(name);
        const idColumn = schema.getIdColumn();
        const id = data[idColumn.name];
        const orql = `delete ${name}(${idColumn.name} = $id)`;
        await this.session.delete(orql, { id });
    }
    async update(name, data) {
        const schema = this.session.getSchema(name);
        const items = [];
        const idColumn = schema.getIdColumn();
        for (const key of Object.keys(data)) {
            if (schema.hasColumn(key) || schema.hasAssociation(key)) {
                if (data[key] != undefined) {
                    items.push(key);
                }
            }
        }
        if (items.length == 0)
            return;
        const orql = `update ${name}(${idColumn.name} = $id): {${items.join(', ')}}`;
        await this.session.update(orql, data);
    }
}
exports.default = UpdateBuilder;
