"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
const mysql_1 = __importDefault(require("mysql"));
class MysqlConnection {
    constructor(options) {
        this.options = options;
        const { host, password, database, username, port } = this.options;
        const mOptions = { host, user: username, password, database, port };
        this.origin = mysql_1.default.createConnection(mOptions);
    }
    async connect() {
        return new Promise((resolve, reject) => {
            this.origin.connect(err => {
                if (err)
                    return reject(err);
                resolve();
            });
        });
    }
    async query(namedParamSql) {
        return new Promise((resolve, reject) => {
            console.log(namedParamSql.toString());
            this.origin.query(namedParamSql.sql, namedParamSql.getParamArray(), (error, results, fields) => {
                if (error)
                    return reject(error);
                const _fields = fields != undefined ? fields.map(info => info.name) : [];
                const _results = results.map(result => {
                    const obj = {};
                    for (const field of _fields) {
                        obj[field] = result[field];
                    }
                    return obj;
                });
                resolve({
                    results: _results,
                    fields: _fields
                });
            });
        });
    }
    async add(namedParamSql) {
        return new Promise((resolve, reject) => {
            console.log(namedParamSql.toString());
            this.origin.query(namedParamSql.sql, namedParamSql.getParamArray(), (error, results, fields) => {
                if (error)
                    return reject(error);
                resolve(results.insertId);
            });
        });
    }
    async update(namedParamSql) {
        return new Promise((resolve, reject) => {
            console.log(namedParamSql.toString());
            this.origin.query(namedParamSql.sql, namedParamSql.getParamArray(), (error, results, fields) => {
                if (error)
                    return reject(error);
                resolve(results.affectedRows);
            });
        });
    }
    async delete(namedParamSql) {
        return await this.update(namedParamSql);
    }
    beginTransaction() {
        return new Promise((resolve, reject) => {
            this.origin.beginTransaction(err => {
                if (err)
                    return reject(err);
                resolve();
            });
        });
    }
    close() {
        return new Promise(resolve => {
            this.origin.end(err => {
                if (err)
                    throw err;
                resolve();
            });
        });
    }
    commit() {
        return new Promise((resolve, reject) => {
            this.origin.commit(err => {
                if (!err)
                    return resolve();
                this.origin.rollback(err => {
                    if (err)
                        return reject(err);
                    resolve();
                });
            });
        });
    }
    rollback() {
        return new Promise((resolve, reject) => {
            this.origin.rollback(err => {
                if (err)
                    return reject(err);
                resolve();
            });
        });
    }
}
module.exports = class MysqlDriver {
    async getConnect(options) {
        const connect = new MysqlConnection(options);
        await connect.connect();
        return connect;
    }
};
