"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ResultMapper_1 = require("./ResultMapper");
function id(options = {}) {
    const name = options.name || 'id';
    const field = options.field || name;
    return { id: true, name, field };
}
exports.id = id;
function column(name, options = {}) {
    const field = options.field || name;
    return { column: true, name, field };
}
exports.column = column;
function object(name, children) {
    return { object: true, name, children };
}
exports.object = object;
function array(name, children) {
    return { array: true, name, children };
}
exports.array = array;
class Mapper {
    static create(children) {
        let resultId;
        const columns = [];
        for (const options of children) {
            if (typeof options == 'string') {
                columns.push(new ResultMapper_1.ResultColumn(options));
            }
            else {
                if (options.id) {
                    resultId = new ResultMapper_1.ResultId(options.name, options.type, options.field);
                }
                else if (options.column) {
                    columns.push(new ResultMapper_1.ResultColumn(options.name, options.type, options.field));
                }
                else if (options.object) {
                    columns.push(new ResultMapper_1.ResultObject(options.name, Mapper.create(options.children)));
                }
                else if (options.array) {
                    columns.push(new ResultMapper_1.ResultArray(options.name, Mapper.create(options.children)));
                }
            }
        }
        return new ResultMapper_1.ResultRoot(resultId, columns);
    }
}
exports.default = Mapper;
