"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const OrqlNode_1 = require("orql-parser/lib/OrqlNode");
const ResultMapper_1 = require("./ResultMapper");
/**
 * 负责将orql node转化为result mapper
 */
class OrqlResultMapper {
    constructor(schemaManager) {
        this.caches = new Map();
        this.schemaManager = schemaManager;
    }
    toResult(item) {
        if (this.caches.has(item))
            return this.caches.get(item);
        const schema = this.schemaManager.getSchema(item.name);
        // FIXME 抛出异常
        const resultRoot = this._toResult(item, schema, schema.table);
        this.caches.set(item, resultRoot);
        return resultRoot;
    }
    _toResult(refItem, schema, path) {
        let resultId;
        const columns = [];
        let hasAll = false;
        const ignores = [];
        for (const item of refItem.children) {
            if (item instanceof OrqlNode_1.OrqlAllItem) {
                hasAll = true;
            }
            else if (item instanceof OrqlNode_1.OrqlIgnoreItem) {
                ignores.push(item.name);
            }
            else if (schema.hasColumn(item.name)) {
                const column = schema.getColumn(item.name);
                // FIXME
                const columnPath = path != undefined ? `${path}_${column.field}` : column.field;
                if (column.primaryKey) {
                    resultId = new ResultMapper_1.ResultId(column.name, column.type, columnPath);
                }
                else {
                    const resultColumn = new ResultMapper_1.ResultColumn(column.name, column.type, columnPath);
                    columns.push(resultColumn);
                }
            }
            else if (schema.hasAssociation(item.name)) {
                if (item.children == undefined || item.children.length == 0)
                    continue;
                const itemPath = path != undefined ? `${path}_${item.name}` : item.name;
                const association = schema.getAssociation(item.name);
                if (item.isArray) {
                    const rootResult = this._toResult(item, association.ref, itemPath);
                    const resultObject = new ResultMapper_1.ResultArray(item.name, rootResult);
                    columns.push(resultObject);
                }
                else {
                    const rootResult = this._toResult(item, association.ref, itemPath);
                    const resultObject = new ResultMapper_1.ResultObject(item.name, rootResult);
                    columns.push(resultObject);
                }
            }
        }
        if (hasAll) {
            for (const column of schema.columns) {
                if (!column.refKey && ignores.indexOf(column.name) < 0) {
                    const columnPath = path != undefined ? `${path}_${column.field}` : column.field;
                    if (column.primaryKey) {
                        resultId = new ResultMapper_1.ResultId(column.name, column.type, columnPath);
                    }
                    else {
                        const resultColumn = new ResultMapper_1.ResultColumn(column.name, column.type, columnPath);
                        columns.push(resultColumn);
                    }
                }
            }
        }
        if (!resultId) {
            // 插入id用于mappe
            const idColumn = schema.getIdColumn();
            if (idColumn) {
                const columnPath = path != undefined ? `${path}_${idColumn.field}` : idColumn.field;
                resultId = new ResultMapper_1.ResultId(idColumn.name, idColumn.type, columnPath);
            }
        }
        return new ResultMapper_1.ResultRoot(resultId, columns);
    }
}
exports.default = OrqlResultMapper;
