"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class ResultRoot {
    constructor(id, columns) {
        this.id = id;
        this.columns = columns;
    }
}
exports.ResultRoot = ResultRoot;
class ResultItem {
    constructor(column) {
        this.column = column;
    }
}
exports.ResultItem = ResultItem;
// 普通列
class ResultColumn extends ResultItem {
    constructor(column, type, field = column) {
        super(column);
        this.field = field;
        this.type = type;
    }
}
exports.ResultColumn = ResultColumn;
// id列
class ResultId extends ResultColumn {
}
exports.ResultId = ResultId;
// 关联对象
class ResultRef extends ResultItem {
    constructor(column, root) {
        super(column);
        this.root = root;
    }
}
exports.ResultRef = ResultRef;
// object对象
class ResultObject extends ResultRef {
}
exports.ResultObject = ResultObject;
// 数组对象
class ResultArray extends ResultRef {
}
exports.ResultArray = ResultArray;
// query results mapper
class ResultMapper {
    mappe(resultRoot, results) {
        const data = [];
        const resultId = resultRoot.id;
        // 按id切割, {id: {}[]}
        const idListMap = new Map();
        for (const result of results) {
            // 没有id的，全部按单个切割
            // TODO 优化为查出的键关联作为主键
            const idValue = resultId ? result[resultId.field] : result;
            // 避免undefined列被映射
            if (idValue == undefined)
                continue;
            if (!idListMap.has(idValue))
                idListMap.set(idValue, []);
            idListMap.get(idValue).push(result);
        }
        for (const [idValue, idResults] of idListMap) {
            const childData = {};
            // 从第一列获取id数据
            const idResult = idResults[0];
            if (resultId) {
                childData[resultId.column] = idValue;
            }
            for (const resultItem of resultRoot.columns) {
                if (resultItem instanceof ResultColumn) {
                    childData[resultItem.column] = idResult[resultItem.field];
                }
                else if (resultItem instanceof ResultRef) {
                    const nestRecord = this.mappe(resultItem.root, idResults);
                    if (resultItem instanceof ResultObject) {
                        // 只填入一个值
                        childData[resultItem.column] = nestRecord.length == 0 ? undefined : nestRecord[0];
                    }
                    else if (resultItem instanceof ResultArray) {
                        childData[resultItem.column] = nestRecord;
                    }
                }
            }
            data.push(childData);
        }
        return data;
    }
}
exports.default = ResultMapper;
