"use strict";
module.exports = class Sqlite3Migration {
    async create(session) {
        const schemas = session.schemaManager.schemas;
        for (const [name, schema] of schemas.entries()) {
            await this.createTable(session, schema);
        }
    }
    async createTable(session, schema) {
        const columns = schema.columns.map(column => this.genCreateColumn(column));
        const sql = `create table if not exists ${schema.table} (${columns.join(', ')})`;
        await session.nativeUpdate(sql);
    }
    genCreateColumn(column) {
        let sql = `${column.field} ${this.genColumnType(column)}`;
        if (column.primaryKey)
            sql += ' primary key';
        if (column.generatedKey)
            sql += ' autoincrement';
        if (!column.primaryKey && column.required)
            sql += ' not null';
        return sql;
    }
    genColumnType(column) {
        let type = column.type.toString();
        switch (type) {
            case 'int':
                type = 'integer';
                break;
            case 'string':
                type = 'varchar';
                break;
        }
        return column.length != undefined && column.length > 0 ? `${type}(${column.length})` : `${type}`;
    }
    async renameTable(session, oldName, newName) {
    }
    async drop(session) {
        const schemas = session.schemaManager.schemas;
        for (const [name, schema] of schemas.entries()) {
            const exist = await this.existsTable(session, schema.name);
            if (exist) {
                await session.nativeUpdate(`drop table ${schema.table}`);
            }
        }
    }
    async existsTable(session, name) {
        const result = await session.nativeQuery(`select count(*) FROM sqlite_master where type='table' and name='${name}'`);
        return result[0].get(0) == 1;
    }
    async dropTable(session, name) {
    }
    async update(session) {
        const database = session.configuration.connectionOptions.database;
        const schemas = session.schemaManager.schemas;
        for (const schema of schemas) {
            const exist = await this.existsTable(session, schema.table);
            if (!exist) {
                await this.createTable(session, schema);
            }
            else {
                const { results } = await session.nativeQuery(`pragma table_info('${schema.table}')`);
                const fieldNames = results.map(field => field.name);
                for (const column of schema.columns) {
                    const index = fieldNames.indexOf(column.field);
                    if (index < 0) {
                        await session.nativeUpdate(`alter table ${schema} add column ${this.genCreateColumn(column)}`);
                    }
                }
            }
        }
    }
    async addColumn(session, schema, column) {
    }
    async addFKColumn(session, schema, column) {
    }
    async queryAllColumn(session, schema) {
        return [];
    }
    async queryColumn(session, schema, column) {
        return undefined;
    }
    shouldUpdateColumn(column, databaseColumn) {
        return false;
    }
    async updateColumn(session, schema, column, oldField) {
        return undefined;
    }
    async addFK(session, schema, column) {
    }
    async queryFK(session, schema, column) {
        return undefined;
    }
    shouldUpdateFK(column, fkColumn) {
        return false;
    }
    async updateFK(session, schema, column) {
    }
    async dropFK(session, schema, column) {
    }
};
