export default class SqlNode {
}
/**
 * 数据操作
 */
export declare class SqlDML extends SqlNode {
}
export declare class SqlInsert extends SqlDML {
    readonly table: string;
    readonly columns: SqlColumn[];
    readonly params: SqlParam[];
    constructor(table: string, columns: Array<SqlColumn>, params: Array<SqlParam>);
}
export declare class SqlDelete extends SqlDML {
    readonly table: string;
    readonly where: SqlExp;
    constructor(table: string, where: SqlExp);
}
export declare class SqlUpdate extends SqlDML {
    readonly table: string;
    readonly where: SqlExp;
    readonly sets: SqlSet[];
    constructor(table: string, where: SqlExp, sets: SqlSet[]);
}
export declare class SqlQuery extends SqlDML {
    readonly select: Array<SqlColumn>;
    readonly from: SqlForm;
    readonly where: Array<SqlExp>;
    readonly joins: Array<SqlJoin>;
    readonly page?: SqlPage;
    readonly orders: Array<SqlOrder>;
    constructor(select: Array<SqlColumn>, from: SqlForm, where: Array<SqlExp>, joins: Array<SqlJoin>, orders: Array<SqlOrder>, page?: SqlPage);
}
export declare class SqlExp {
}
export declare class SqlLogicExp extends SqlExp {
    readonly left: SqlExp;
    readonly op: SqlLogicOp;
    readonly right: SqlExp;
    constructor(left: SqlExp, op: SqlLogicOp, right: SqlExp);
}
export declare class SqlColumnExp extends SqlExp {
    readonly left: SqlColumn;
    readonly op: SqlCompareOp;
    readonly right: SqlColumn | SqlParam | SqlValue;
    constructor(left: SqlColumn, op: SqlCompareOp, right: SqlColumn | SqlParam | SqlValue);
}
export declare class SqlNestExp extends SqlExp {
    readonly exp: SqlExp;
    constructor(exp: SqlExp);
}
export declare class SqlParam {
    readonly name: string;
    constructor(name: string);
}
export declare class SqlValue {
    readonly value: any;
    constructor(value: any);
}
export declare enum SqlCompareOp {
    Ge = 0,
    Gt = 1,
    Eq = 2,
    Le = 3,
    Lt = 4,
    Ne = 5,
    Like = 6
}
export declare enum SqlLogicOp {
    And = 0,
    Or = 1
}
export declare class SqlColumn {
    readonly name: string;
    readonly table?: string;
    constructor(name: string, table?: string);
}
export declare class SqlCountColumn extends SqlColumn {
}
export declare class SqlSet {
    readonly name: string;
    readonly param: string;
    constructor(name: string, param: string);
}
export declare class SqlForm {
}
export declare class SqlTableForm extends SqlForm {
    readonly table: SqlTable;
    constructor(table: SqlTable);
}
export declare class SqlInnerFrom extends SqlForm {
    readonly query: SqlQuery;
    constructor(query: SqlQuery);
}
export declare class SqlJoin {
    readonly table: string;
    readonly alias: string;
    readonly type: SqlJoinType;
    readonly on: SqlExp;
    constructor(table: string, alias: string, type: SqlJoinType, on: SqlExp);
}
export declare enum SqlJoinType {
    Inner = 0,
    Left = 1
}
export declare class SqlPage {
    offset?: number;
    limit?: number;
    constructor(offset?: number, limit?: number);
}
export declare class SqlOrder {
    readonly sort: string;
    readonly columns: Array<SqlColumn>;
    constructor(sort: string, columns: Array<SqlColumn>);
}
export declare class SqlTable {
    readonly name: string;
    readonly alias: string;
    constructor(name: string, alias?: string);
}
