"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const os_1 = require("os");
const utils_1 = require("../utils");
var MatchStatus;
(function (MatchStatus) {
    MatchStatus[MatchStatus["State"] = 0] = "State";
    MatchStatus[MatchStatus["Param"] = 1] = "Param";
})(MatchStatus || (MatchStatus = {}));
/**
 * select * from user where id = $id
 */
class NamedParamSql {
    constructor(sql, params) {
        // generated id value
        this.generatedKey = false;
        this.params = params || {};
        this.paramNames = [];
        let status = MatchStatus.State;
        let sqlTmp = '';
        let paramTmp = '';
        for (const c of sql) {
            switch (status) {
                case MatchStatus.State:
                    if (c == '$') {
                        status = MatchStatus.Param;
                        sqlTmp += '?';
                    }
                    else {
                        sqlTmp += c;
                    }
                    break;
                case MatchStatus.Param:
                    if (c == ' ' || c == ')' || c == os_1.EOL || c == ',') {
                        this.paramNames.push(paramTmp);
                        paramTmp = '';
                        status = MatchStatus.State;
                        sqlTmp += c;
                    }
                    else {
                        paramTmp += c;
                    }
                    break;
            }
        }
        if (paramTmp != '')
            this.paramNames.push(paramTmp);
        this.sql = sqlTmp;
    }
    static create(sql, params) {
        return new NamedParamSql(sql, params);
    }
    getParamString(name) {
        const param = utils_1.get(this.params, name);
        if (param == undefined)
            return `${name}: null`;
        return `${name}: ${param}`;
    }
    getParam(name) {
        return utils_1.get(this.params, name);
    }
    getParamArray() {
        return this.paramNames.map(name => this.getParam(name));
    }
    getParamObject() {
        const paramObject = {};
        for (const name of this.paramNames) {
            paramObject[name] = this.getParam(name);
        }
        return paramObject;
    }
    toString() {
        if (this.paramNames.length == 0)
            return `sql: ${this.sql}`;
        return `sql: ${this.sql} params: ${this.paramNames.map(name => this.getParamString(name)).join(', ')}`;
    }
}
exports.default = NamedParamSql;
